@@ -1,7 +1,7 @@
 import numpy as np
 import copy
 
-from ..utils.constants import LOGConstants, JsonConstants
+from ..utils.constants import LOGConstants, JointTypeMapping, ObjectConstantsForData
 
 
 class BinoutData(object):
@@ -345,16 +345,25 @@ class BinoutData(object):
             return True
 
         # i.e.  no rcforc in binout
-        if self._name not in self._binout.read():
+
+        if isinstance(self._name, str):
+            name = self._name
+            display_name = self._name
+        else:
+            name = str(self._name[0])
+            display_name = " ".join(self._name)
+        if name not in self._binout.read():
             return False
 
         # data read
-        self._logger.emit(LOGConstants.READ_BINOUT[0], 'read ' + self._name + ' data ...')
+        self._logger.emit(LOGConstants.READ_BINOUT[0], 'read ' + display_name + ' data ...')
 
-        ls = [self._name]
+        ls = self._name if isinstance(self._name, list) else [self._name]
         ls_subdatatypes = []
         self._get_subdatatypes_to_reach_binout_data(ls, ls_subdatatypes)
 
+        #TODO: check ls_subdatatype does the list have more items??
+
         # go through the extracted subdatatypes and initialize what has been found
         #   cases in where ids are in multiple subtrees are currently not supported (test case jntforces)
         for subdatatypes in ls_subdatatypes:
@@ -368,8 +377,9 @@ class BinoutData(object):
 
             self.__init_data__(subdatatypes)
 
-        self._logger.emit(LOGConstants.READ_BINOUT[0], "done reading " + self._name + "!")
-
+        self._logger.emit(LOGConstants.READ_BINOUT[0], "done reading " + display_name + "!")
+        if isinstance(self._name, list):
+            self._name = self._name[1]
         return True
 
     def _get_negative_intersection(self, data_channel_ids):
@@ -420,6 +430,7 @@ class BinoutData(object):
                 data_delta_t = delta_t
 
         array_definition = array
+
         if array_definition[0].split(',')[0].strip(' (') == "all":
             converted_tuples = [(index, array_definition[0].split(',')[1].strip(' )')) for index, id_ in
                                 enumerate(ids)]
@@ -431,6 +442,10 @@ class BinoutData(object):
 
         data_array = None
         for tpl in converted_tuples:
+            if type == ObjectConstantsForData.JOINT_TYPE:
+                tpl = list(tpl)
+                tpl[1] = JointTypeMapping.lspp_to_dynasaur_mapping(tpl[1])
+                tpl = tuple(tpl)
             d = copy.copy(self.get_measurement_channel(id_=ids[tpl[0]], channel_name=tpl[1]))
             if len(d) == 0:
                 return np.NaN
