@@ -1450,46 +1450,32 @@ class JointForc(BinoutData):
 
         :return:
         """
+        name = ['jntforc', 'joints']
+        BinoutData.__init__(self, data, logger, dynasaur_definitions, name)
 
-        BinoutData.__init__(self, data, logger, dynasaur_definitions, 'jntforc')
 
-    def get_measurement_channel(self, id_, channel_name):
+class JointType(BinoutData):
+    """ """
+    DATA_CHANNEL_TYPES = ['alpha_moment_stiffness', 'd(gamma)_dt', 'joint_extra2',
+                          'alpha_degrees', 'alpha_moment_total', 'gamma_degrees', 'd(alpha)_dt', 'beta_degrees',
+                          'alpha_moment_damping', 'beta_moment_total', 'gamma_scale_factor',
+                          'beta_moment_damping', 'd(beta)_dt', 'beta_moment_stiffness']
+    #TODO: Consider types: 'joint_energy', 'joint_extra1'
+    ids_name = "ids"
+
+    def __init__(self, data, logger, dynasaur_definitions):
         """
+        Initialization/constructor
 
-        Args:
-          id: param channel_name:
-          id_: 
-          channel_name: 
-
-        Returns:
+        :param: binout
+        :param: logger
+        :param: dynasaur definition
+        :param: cody type(MADYMO/LS DYNA)
 
+        :return:
         """
-
-        unit = self._get_unit_dimension_from_channel_name(channel_name)
-
-        if channel_name == 'time':
-            return self._time_interp.reshape(-1, 1)
-
-        if np.issubdtype(self._ids.dtype, np.number):
-            data_index = np.where(int(id_) == self._ids)[0]
-
-        else:  # madymo case ... ids are not numeric
-            data_index = np.where(id_ == self._ids)[0]
-
-        if len(data_index) == 0:
-            self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id_) + ' not in binout')
-            return []
-
-        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
-        assert (len(data_index) >= 1)
-
-        if channel_name not in self._data.keys():
-            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
-            return []
-
-        d = self._data[channel_name][:, data_index]
-
-        return d.reshape(-1, len(data_index)) * unit
+        name = ['jntforc', 'type1']
+        BinoutData.__init__(self, data, logger, dynasaur_definitions, name)
 
 
 class RCForc(BinoutData):
