@@ -30,26 +30,32 @@ class MadymoData:
             else:
                 assert False
 
+    def _extratct_rel_disp_data(self, node, data_type="sbtout"):
+        id_strings = [(signal, ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip())
+                      for signal in node.keys() if signal.startswith("SIGNAL")]
+
+        sig_id_dir = [(signal, *self._get_simplified_out_node_id(id_)) for signal, id_ in id_strings]
+
+        for sig, id_, identifier in sig_id_dir:
+            id_idx = self._d[data_type]["slipring_ids"].index(id_)
+            if identifier == "ring_slip":
+                self._d[data_type]["ring_slip"][:, id_idx] = node[sig]["Y_VALUES"][0, :]
+            else:
+                assert False
+
     def _extract_outlet_data(self, node, data_type="sbtout"):
 
         # extract matching ids
         id_strings = [(signal, ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip())
                       for signal in node.keys() if signal.startswith("SIGNAL")]
 
-        print(id_strings)
+        sig_id_dir = [(signal, id_.split(" ")[0]) for signal, id_ in id_strings]
 
-        sig_id_dir = [(signal, *self._get_simplified_fem_node_id(id_)) for signal, id_ in id_strings]
-
-        for sig, id_, dir_ in sig_id_dir:
+        for sig, id_ in sig_id_dir:
             id_idx = self._d[data_type]["slipring_ids"].index(id_)
-            if dir_[0] == "x":
-                self._d[data_type][DataChannelTypesNodout.X_COORDINATE][:, id_idx] = node[sig]["Y_VALUES"][0, :]
-            elif dir_[0] == "y":
-                self._d[data_type][DataChannelTypesNodout.Y_COORDINATE][:, id_idx] = node[sig]["Y_VALUES"][0, :]
-            elif dir_[0] == "z":
-                self._d[data_type][DataChannelTypesNodout.Z_COORDINATE][:, id_idx] = node[sig]["Y_VALUES"][0, :]
-            else:
-                assert False
+            self._d[data_type]["ring_slip"][:, id_idx] = node[sig]["Y_VALUES"][0, :]
+
+        return
 
     def _extratct_data(self, node, data_type, channel_type, idx_madymo_data, ids_name=None):
         """
@@ -183,6 +189,29 @@ class MadymoData:
 
         return simiplified_id
 
+
+    def _get_simplified_out_node_id(self, id_string):
+        """
+            '/1/2  ( /PBP/PLP_internal_belt ) - untensioned length belt /1/2 (   ) LPFILTER'),
+
+            The function strips the (unnecessary) extracts key words    slip, tensioned length
+            '/1/2, slip
+
+        Args:
+          id_string: full idenfier as read in from the .h5 file
+
+        Returns:
+            simpliefied_id string
+            direction of the channel
+        """
+        id_string_split = id_string.split(" ")
+        system_nr = id_string_split[0]
+        simiplified_id = system_nr
+
+        if id_string.find("slip at"):
+            return simiplified_id, "ring_slip"
+
+
     def _get_simplified_fem_node_id(self, id_string):
         """
             ids in the FEM node time-history output can be of the following format
@@ -236,7 +265,6 @@ class MadymoData:
             # if assert: ID is already in id list
             if simplified_id in self._d[data_type][ids_name]:
                 continue
-
             self._d[data_type][ids_name].append(simplified_id)
             self._d[data_type]["legend_ids"].append(id_string)
 
@@ -363,10 +391,6 @@ class MadymoData:
                             2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
                         self._extratct_data(f["MODEL_0/Linear displacements"], "nodout", data_type,
                                             idx_madymo_data=idx_madymo_data)
-                        # self._extratct_data(f["/MODEL_0/Relative displacements"], "nodout", data_type,
-                        #                    idx_madymo_data=idx_madymo_data)
-                        # self._extratct_data(f["/MODEL_0/Retractor | pretensioner | load limiter | tying"], "nodout", data_type,
-                        #                    idx_madymo_data=idx_madymo_data)
 
                 if "FEM node time-history output" in f["MODEL_0"].keys():
                     self._extract_fem_node_data(f["MODEL_0/FEM node time-history output"], "nodout")
@@ -406,16 +430,15 @@ class MadymoData:
 
                 dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['slipring_ids']))
                 data_types_to_be_filled = ["ring_slip"]
-                print(data_types_to_be_filled)
                 for data_type in data_types_to_be_filled:
                     self._d['sbtout'][data_type] = np.empty(dimension)
                     self._d['sbtout'][data_type][:] = np.nan
 
-                self._extract_outlet_data(f["MODEL_0/Retractor | pretensioner | load limiter | tying"],
+                if "Retractor | pretensioner | load limiter | tying" in f["MODEL_0"].keys():
+                    self._extract_outlet_data(f["MODEL_0/Retractor | pretensioner | load limiter | tying"],
                                           data_type="sbtout")
-                #self._extratct_data(f["MODEL_0/Retractor | pretensioner | load limiter | tying"], "sbtout",
-                #                        data_type, idx_madymo_data=0, ids_name="slipring_ids")
-                # TODO
+                if "Relative displacements" in f["MODEL_0"].keys():
+                    self._extratct_rel_disp_data(f["/MODEL_0/Relative displacements"], data_type="sbtout")
 
                 #dimension = (self._d['sbtout']['time'].shape[0], len(self._d['sbtout']['belt_ids']))
                 #data_types_to_be_filled = ["belt_force", "belt_length"]# i for i in self._d['sbtout'].keys() if i != "ids" and i != "time" and i != "legend_ids"]
@@ -481,8 +504,7 @@ class MadymoData:
             if "COMP" in node.name.split("/"):
                 if 'nodout' not in self._d.keys():
                     if node.parent.name.split("/")[-1].startswith("Angular ") or \
-                            node.parent.name.split("/")[-1].startswith("Linear ") or \
-                            node.parent.name.split("/")[-1].startswith():
+                            node.parent.name.split("/")[-1].startswith("Linear "):
                         self._d['nodout'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'glstat' not in self._d.keys():
@@ -504,7 +526,8 @@ class MadymoData:
                         self._d['secforc'] = {"ids": [], "legend_ids": [], "time": None}
 
                 if 'sbtout' not in self._d.keys():
-                    if node.parent.name.split("/")[-1].startswith('Retractor | pretensioner | load limiter | tying'):
+                    if node.parent.name.split("/")[-1].startswith('Retractor | pretensioner | load limiter | tying') or \
+                       node.parent.name.split("/")[-1].startswith('Relative displacement'):
                         self._d['sbtout'] = {"belt_ids": [], "slipring_ids": [], "legend_ids": [], "time": None}
 
                 if node.parent.name.split("/")[-1].startswith("Energy output"):
@@ -519,7 +542,7 @@ class MadymoData:
                     self._add_ids(node.parent, data_type="nodout")
                     self._add_time(node.parent, data_type="nodout")
 
-                elif node.parent.name.split("/")[-1].startswith("Angular velocity"):
+                elif node.parent.name.split("/")[-1].startswith("Angular velocities"):
                     self._d['nodout'][DataChannelTypesNodout.RX_VELOCITY] = None
                     self._d['nodout'][DataChannelTypesNodout.RY_VELOCITY] = None
                     self._d['nodout'][DataChannelTypesNodout.RZ_VELOCITY] = None
@@ -583,10 +606,20 @@ class MadymoData:
                     self._add_time(node.parent, data_type="secforc")
 
                 elif node.parent.name.split("/")[-1].startswith("Retractor | pretensioner | load limiter | tying"):
-                    self._d["sbtout"][DataChannelTypesSbtout.RING_SLIP] = None
+                    if not DataChannelTypesSbtout.RING_SLIP in self._d["sbtout"]:
+                        self._d["sbtout"][DataChannelTypesSbtout.RING_SLIP] = None
+
                     self._add_ids(node.parent, data_type="sbtout", sbtout="slipring")
                     self._add_time(node.parent, data_type="sbtout")
 
+                elif node.parent.name.split("/")[-1].startswith("Relative displacements"):
+                    if not DataChannelTypesSbtout.RING_SLIP in self._d["sbtout"]:
+                        self._d["sbtout"][DataChannelTypesSbtout.RING_SLIP] = None
+
+                    self._add_ids(node.parent, data_type="sbtout", sbtout="slipring")
+                    self._add_time(node.parent, data_type="sbtout")
+
+
     def read(self, *argv):
         """read function to access Madymo data in a similar way as reading binout files in:
         https://lasso-gmbh.github.io/lasso-python/build/html/dyna/Binout.html
