@@ -120,6 +120,7 @@ class DefinitionConstants(object):
     DATA_VIS = "DATA VISUALIZATION"
     RISK_FUNCTION = "RISK FUNCTION"
     CRITERIA = "CRITERIA"
+    OFFSET = "OFFSET"
 
 
 class TestConstants:
@@ -148,6 +149,7 @@ class ObjectConstantsForData:
     DISCRETE = "DISCRETE"
     NODE = "NODE"
     JOINT = "JOINT"
+    JOINT_TYPE = "JOINT_TYPE"
     SEAT_BELT = "SEAT_BELT"
     SLIP_RING = "SLIP_RING"
     CONTACT = "CONTACT"
@@ -160,6 +162,38 @@ class ObjectConstantsForData:
     BOUNDARY_CONDITION = "BOUNDARY_CONDITION"
 
 
+class JointTypeMapping:
+    mapping = [('alpha_moment_stiffness', 'phi_moment_stiffnes'),
+               ('d(gamma)_dt', 'd_theta_d_t'),
+               ('joint_extra2', 'joint_energy'),
+               ('alpha_degrees', 'phi_degrees'),
+               ('alpha_moment_total', 'phi_moment_total'),
+               ('gamma_degrees', 'theta_degrees'),
+               ('d(alpha)_dt', 'phi_dt'),
+               ('beta_degrees', 'psi_degrees'),
+               ('alpha_moment_damping', 'phi_moment_damping'),
+               ('beta_moment_total', 'psi_moment_total'),
+               ('gamma_scale_factor', 'theta_scale_factor'),
+               ('beta_moment_damping', 'psi_moment_damping'),
+               ('d(beta)_dt', 'd_psi_d_t'),
+               ('beta_moment_stiffness', 'psi_moment_stiffness')]
+
+    @staticmethod
+    def lspp_to_dynasaur_mapping(channel_type):
+        """
+
+        Args:
+          binary_data_type: return:
+
+        Returns:
+
+        """
+
+        for tpl in JointTypeMapping.mapping:
+            if tpl[1] == channel_type:
+                return tpl[0]
+
+
 class DataTypeMapping:
     """ """
     mapping = [(ObjectConstantsForData.ELEMENT, "elout"),
@@ -167,7 +201,8 @@ class DataTypeMapping:
                (ObjectConstantsForData.AIRBAG_CPM, "abstat_cpm"),
                (ObjectConstantsForData.CROSS_SECTION, "secforc"),
                (ObjectConstantsForData.NODE, "nodout"),
-               (ObjectConstantsForData.JOINT, "jntforc"),
+               (ObjectConstantsForData.JOINT, "joints"),
+               (ObjectConstantsForData.JOINT_TYPE, "type1"),
                (ObjectConstantsForData.SEAT_BELT, "sbtout"),
                (ObjectConstantsForData.SLIP_RING, "sbtout"),
                (ObjectConstantsForData.CONTACT, "rcforc"),
@@ -214,6 +249,7 @@ class DataTypeMapping:
 
         return None
 
+
 class JsonConstants:
     """ """
     TYPE = "type"
